`sound_source_id`, a program for sound source identification testing.
Webpage: https://samcarcagno.altervista.org/sound_source_id/sound_source_id.html

Copyright 2022-2023 Samuele Carcagno <sam.carcagno@gmail.com>



